@@ -1,7 +1,12 @@
+from __future__ import (
+    absolute_import,
+    division,
+    print_function,
+    unicode_literals,
+)
 import re
-import logbook
 
-logger = logbook.Logger(__name__)
+import logbook
 
 
 DEFAULT_FORMAT_CHOICES = {
@@ -15,16 +20,20 @@ DEFAULT_FORMAT_CHOICES = {
 
 
 class Parser(object):
-    def __init__(self, format_):
+    def __init__(self, format_=""):
         self._format = DEFAULT_FORMAT_CHOICES.get(format_) or format_
         self._keys = re.findall("\?P<(.*?)>", self._format)
         self._line_re = re.compile(self._format)
+        self._logger = logbook.Logger(__name__)
 
     def parse(self, line):
+        if hasattr(line, "decode"):
+            line = line.decode()
+
         pattern = self._line_re.search(line)
         try:
             return dict(zip(self._keys, pattern.groups()))
         except AttributeError:
-            logger.warn(
+            self._logger.warn(
                 "line doesn't match the format {!r}".format(self._format))
             return
